<?php
/**
 * Theme custom sanitize functions
 *
 * @subpackage kanagata
 * @version    1.3.0
 * @since      1.2.2
 */

/**
 * Check whether the correct css color property
 *
 * @param string $color css color string.
 *
 * @return boolean
 */
function kanagata_is_color( $color ) {
	if ( '' === $color ) {
		return false;
	}
	// 3 or 6 hex digits, or the empty string.
	if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize css color
 *
 * @param string $color css color string.
 *
 * @return string sanitized color.
 */
function kanagata_sanitize_color( $color ) {
	// 3 or 6 hex digits, or the empty string.
	if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
		return $color;
	}
	return '';
}

/**
 * Check whether float property is left or right
 *
 * Kanagata uses left or right. not none.
 *
 * @param string $value Value is left or right.
 *
 * @return boolean
 */
function kanagata_is_sidebar_layout( $value ) {
	 $float = array( 'left', 'right', 'bottom' );
	if ( in_array( $value, $float ) ) {
		return true;
	}

	return false;
}

/**
 * Sanitize sidebar layout
 *
 * If value is not left or right then return 'right'.
 *
 * @param string $value value is left or right.
 *
 * @return string left or right
 */
function kanagata_sanitize_sidebar_layout( $value ) {
	if ( kanagata_is_sidebar_layout( $value ) ) {
		return $value;
	}

	return 'right';
}

/**
 * Sanitize footer position
 *
 * If value is not (left | center | right) then return string 'left'.
 *
 * Center does not work well. So that center return left(since 1.4.3).
 *
 * @param string $value value is left, center, right.
 *
 * @return string left, right
 */
function kanagata_sanitize_footer( $value ) {
	if ( ! in_array( $value, array( 'left', 'center', 'right' ) ) ) {
		return 'left';
	}
	if ( 'center' === $value ) {
		return 'left';
	}

	return $value;
}

/**
 * Sanitize select and radio button.
 *
 * @see https://github.com/WPTT/code-examples/blob/master/customizer/sanitization-callbacks.php
 * @see sanitize_key()               https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param  string               $input   Slug to sanitize.
 * @param  WP_Customize_Setting $setting Setting instance.
 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
 */
function kanagata_sanitize_select( $input, $setting ) {
	 $input  = sanitize_key( $input );
	$choices = $setting->manager->get_control( $setting->id )->choices;

	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Sanitize textarea
 *
 * linebreak is <br>.
 */
function kanagata_sanitize_textarea( $input ) {
	return htmlspecialchars( $input, ENT_QUOTES, 'UTF-8' );
}
